==> kalarm-17.03.80.tar.xz: kalarm-17.03.80/src/templatelistview.h <==
/*
 *  templatelistview.h  -  widget showing list of alarm templates
 *  Program:  kalarm
 *  Copyright © 2007,2008 by David Jarvie <djarvie@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef TEMPLATELISTVIEW_H
#define TEMPLATELISTVIEW_H

#include "kalarm.h"

#include "eventlistview.h"


class TemplateListView : public EventListView
{
        Q_OBJECT
    public:
        explicit TemplateListView(QWidget* parent = nullptr);
        void setModel(QAbstractItemModel*) Q_DECL_OVERRIDE;
};

class TemplateListDelegate : public EventListDelegate
{
        Q_OBJECT
    public:
        explicit TemplateListDelegate(TemplateListView* parent = nullptr)
                   : EventListDelegate(parent) {}
        void edit(KAEvent*, EventListView*) Q_DECL_OVERRIDE;
};

#endif // TEMPLATELISTVIEW_H

// vim: et sw=4:

==> kalarm-20.03.90.tar.xz: kalarm-20.03.90/src/templatelistview.h <==
/*
 *  templatelistview.h  -  widget showing list of alarm templates
 *  Program:  kalarm
 *  Copyright © 2007,2008 by David Jarvie <djarvie@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef TEMPLATELISTVIEW_H
#define TEMPLATELISTVIEW_H

#include "kalarm.h"

#include "eventlistview.h"


class TemplateListView : public EventListView
{
        Q_OBJECT
    public:
        explicit TemplateListView(QWidget* parent = nullptr);
        void setModel(QAbstractItemModel*) override;
};

class TemplateListDelegate : public EventListDelegate
{
        Q_OBJECT
    public:
        explicit TemplateListDelegate(TemplateListView* parent = nullptr)
                   : EventListDelegate(parent) {}
        void edit(KAEvent*, EventListView*) override;
};

#endif // TEMPLATELISTVIEW_H

// vim: et sw=4:
